import { withSentryConfig } from "@sentry/nextjs";

/** @type {import('next').NextConfig} */
const nextConfig = {
  output: "standalone",
  images: {
    remotePatterns: [
      {
        protocol: "https",
        hostname: "git.fascinated.cc",
        pathname: "/**",
      },
      {
        protocol: "https",
        hostname: "api.mcutils.xyz",
        pathname: "/**",
      },
    ],
  },
  experimental: {
    mdxRs: true,
  },
};

export default withSentryConfig(
  nextConfig,
  {
    // For all available options, see:
    // https://github.com/getsentry/sentry-webpack-plugin#options
    silent: true,
    org: "minecraft-utilities",
    project: "frontend",
    url: "https://glitchtip.fascinated.cc/",
    authToken: process.env.SENTRY_AUTH_TOKEN || "",
  },
  {
    // For all available options, see:
    // https://docs.sentry.io/platforms/javascript/guides/nextjs/manual-setup/

    // Upload a larger set of source maps for prettier stack traces (increases build time)
    widenClientFileUpload: true,

    // Hides source maps from generated client bundles
    hideSourceMaps: true,

    // Automatically tree-shake Sentry logger statements to reduce bundle size
    disableLogger: true,
  },
);
